LoggerInterceptor class

Implemented types

Constructors

LoggerInterceptor()

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of this interceptor, used for identification in logs and output.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

afterExecute(dynamic output, InterceptorContext context) FutureOr
Called after the use case's _execute method successfully completes.
override
beforeExecute(dynamic input, InterceptorContext context) FutureOr
Called before the use case's _execute method.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(Object error, InterceptorContext context) FutureOr<void>
Called when an error is thrown during the use case execution.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited