Actor class abstract
Represents a user or system that can perform actions.
The Actor is passed to use cases to perform authorization checks.
Constructors
- Actor()
Properties
- businessId → String
-
Business context identifier for multitenancy support.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for this actor.
no setter
-
permissions
↔ List<
Permission> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String
-
Retrieves the authentication token for the actor.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited