LoggerInterceptor class
- Implemented types
Constructors
Properties
Methods
-
afterExecute(
dynamic output, InterceptorContext context) → FutureOr -
Called after the use case's
_executemethod successfully completes.override -
beforeExecute(
dynamic input, InterceptorContext context) → FutureOr -
Called before the use case's
_executemethod.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
Object error, InterceptorContext context) → FutureOr< void> -
Called when an error is thrown during the use case execution.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited