Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
transaction<T>(String tenantId, Future<T> body(UnitOfWork uow))
→ Future<T>
-
Creates a new transaction with tenant isolation
@param tenantId The tenant context for this transaction
@param body The transactional work to execute